@@ -2,7 +2,7 @@
 # housekeeping
 ########################################################################
 
-package Parallel::Queue::Manager;
+package Parallel::Queue::Manager v4.0.2;
 use v5.24;
 use mro qw( c3 );
 
